<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field</source>
        <translation>Поле</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field name</source>
        <translation>Имя поля</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Field description</source>
        <translation>Описание поля</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Field value</source>
        <translation>Значение поля</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Выйти при закрытии</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Запоминать позицию</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Определение имен компьютеров</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Определение имен служб</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>Треугольнички в дереве</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>Линии в дереве</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Сохранять настройки при выходе</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Выделение: копировать PID&apos;ы в буфер обмена</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Нормализовать NICE</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Использовать pmap для имен карт памяти</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>Линейный</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>Иерархический</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>Поток</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>Все процессы</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>Ваши процессы</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Пользовательские процессы</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>Выполняющиеся процессы</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Пауза (Ctrl+пробел)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Процесс %1 ( %2 ) - подробности</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Сокеты</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Карта памяти</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Окружение</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Все поля</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable</source>
        <translation>Переменная</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable name</source>
        <translation>Имя переменной окружения</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Variable value</source>
        <translation>Значение переменной</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Выбор полей пользователя </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>File descriptor</source>
        <translation>Дескриптор файла</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Open mode</source>
        <translation>Режим открытия</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>File name (if available)</source>
        <translation>Имя файла (если доступно)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="782"/>
        <source>I/O Summary:</source>
        <translation>Сводка ввода/вывода:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="816"/>
        <source>No input or output</source>
        <translation>Нет ввода или вывода</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Изменить период обновления</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Новый период обновления</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Неверное значение</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Диапазон адресов</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Отображенные адреса (шестн.)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Кбайт в отображении (десят.)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation>Разр.</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Флаги разрешений</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Смещение</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Смещение в файле до начала отображения (шестн.)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Устр-во</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Верхнее и нижнее число устройства (десят.)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Номер Inode (десят.)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Имя файла (если доступно)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Разрешения</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Пароль суперпользователя</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>Параметр</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>Делить %ЦП на</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>Число ЦП: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>Один ЦП: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>для разработчика</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2618"/>
        <source>PID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2618"/>
        <source>Process ID</source>
        <translation>ID процесса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2620"/>
        <source>TGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2620"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>ID группы задач (родителя потоков)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2622"/>
        <source>PPID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2622"/>
        <source>Parent process ID</source>
        <translation>ИД родительского процесса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2624"/>
        <source>PGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2624"/>
        <source>Process group ID</source>
        <translation>ИД группы процессов</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2626"/>
        <source>SID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2626"/>
        <source>Session ID</source>
        <translation>ИД сеанса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2628"/>
        <source>TTY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2628"/>
        <source>Terminal</source>
        <translation>Терминал</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2630"/>
        <source>TPGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2630"/>
        <source>Process group ID of tty owner</source>
        <translation>ИД группы процесса владельца терминала</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2632"/>
        <source>USER</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2632"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Пользователь (*=suid root, +=suid пользоват.)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2634"/>
        <source>GROUP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2634"/>
        <source>Group name (*=sgid other)</source>
        <translation>Имя группы (*=sgid other)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2636"/>
        <source>UID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2636"/>
        <source>Real user ID</source>
        <translation>Настоящий ИД пользователя</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2638"/>
        <source>EUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2638"/>
        <source>Effective user ID</source>
        <translation>Эффективный ИД пользователя</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2640"/>
        <source>SUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2640"/>
        <source>Saved user ID (Posix)</source>
        <translation>Сохранённый ИД пользователя (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2642"/>
        <source>FSUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2642"/>
        <source>File system user ID</source>
        <translation>ИД пользователя для контроля доступа к ФС</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2644"/>
        <source>GID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2644"/>
        <source>Real group ID</source>
        <translation>Настоящий ИД группы</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2646"/>
        <source>EGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2646"/>
        <source>Effective group ID</source>
        <translation>Эффективный ИД группы</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2648"/>
        <source>SGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2648"/>
        <source>Saved group ID (Posix)</source>
        <translation>Сохранённый ИД группы (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2650"/>
        <source>FSGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2650"/>
        <source>File system group ID</source>
        <translation>ИД группы для контроля доступа к ФС</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2652"/>
        <source>PRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2652"/>
        <source>Dynamic priority</source>
        <translation>Динамический приоритет</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2654"/>
        <source>NICE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2654"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Предпочтение планировщика (выше -&gt; меньше времени ЦП)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2656"/>
        <source>NLWP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2656"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Число задач (потоков) в группе задач</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2658"/>
        <source>PLCY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2658"/>
        <source>Scheduling policy</source>
        <translation>Политика планировщика</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2660"/>
        <source>RPRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2660"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Приоритет реального времени (0-99, чем больше тем лучше)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2662"/>
        <source>TMS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2662"/>
        <source>Time slice in milliseconds</source>
        <translation>Длительность временного среза в миллисекундах</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2664"/>
        <source>%SAVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2664"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Среднее время сна в процентах (-1 -&gt; недоступно)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2666"/>
        <source>CPUSET</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2666"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Маска привязки ЦП (0 -&gt; API не поддерживается)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2668"/>
        <source>MAJFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2668"/>
        <source>Number of major faults (disk access)</source>
        <translation>Число значительных отказов страницы (с обращением к диску)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>MINFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Число незначительных отказов страницы (без обращения к диску)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2673"/>
        <source>VSIZE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2673"/>
        <source>Virtual image size of process</source>
        <translation>Размер виртуального образа</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2675"/>
        <source>RSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2675"/>
        <source>Resident set size</source>
        <translation>Размер резидентного набора</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2677"/>
        <source>MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2677"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>Использование памяти (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2679"/>
        <source>TRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2679"/>
        <source>Text(code) resident set size</source>
        <translation>Размер резидентного набора текста(кода)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2681"/>
        <source>DRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2681"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>Размер резидентного набора данных (malloc+глоб. перем.)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2683"/>
        <source>STACK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2683"/>
        <source>Stack size</source>
        <translation>Размер стека</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2685"/>
        <source>SHARE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2685"/>
        <source>Shared memory with other libs</source>
        <translation>Память, разделенная с другими библиотеками</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2687"/>
        <source>SWAP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2687"/>
        <source>Kbytes on swap device</source>
        <translation>Kбайт на устройстве подкачки</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2689"/>
        <source>IO_R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2689"/>
        <source>io read (file)</source>
        <translation>Прочитано ввода (файлы)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2691"/>
        <source>IO_W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2691"/>
        <source>io write (file)</source>
        <translation>Записано вывода (файлы)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2693"/>
        <source>DT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2693"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Число «грязных» (незаписанных) страниц</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2695"/>
        <source>STAT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2695"/>
        <source>State of the process </source>
        <translation>Состояние процесса </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2697"/>
        <source>FLAGS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2697"/>
        <source>Process flags (hex)</source>
        <translation>Флаги процесса (шестн.)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2699"/>
        <source>WCHAN</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2699"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Функция ядра, в которой спит процесс</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2701"/>
        <source>%WCPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2701"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Взвешенный процент ЦП (среднее за 30 с.)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2703"/>
        <source>%CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2703"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Процент ЦП с момента последнего обновления</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2705"/>
        <source>%MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2705"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Процент использования памяти (RSS/всего)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2707"/>
        <source>START</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2707"/>
        <source>Time process started</source>
        <translation>Время запуска процесса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2709"/>
        <source>TIME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2709"/>
        <source>Total CPU time used since start</source>
        <translation>Общее время ЦП с момента запуска</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2711"/>
        <source>CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2711"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>ЦП, на котором выполняется процесс (системы SMP)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2713"/>
        <source>the process name</source>
        <translation>Имя процесса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2713"/>
        <source>Process Name</source>
        <translation>Имя процесса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2717"/>
        <source>CWD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2717"/>
        <source>Current working directory</source>
        <translation>Текущий рабочий каталог</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>ROOT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Root directory of process</source>
        <translation>Корневой каталог процесса</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2721"/>
        <source>COMMAND_LINE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2721"/>
        <source>Command line that started the process</source>
        <translation>Командная строка процесса</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1638"/>
        <source>Show</source>
        <translation>Показать окно</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1641"/>
        <source>Hide</source>
        <translation>Скрыть окно</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1646"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation>Пользователь: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation>Система: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation>Хорошее: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="471"/>
        <location filename="../infobar.cpp" line="506"/>
        <source>Total: </source>
        <translation>Общее: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="512"/>
        <source>Used: </source>
        <translation>Используемое: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="478"/>
        <source>Cached: </source>
        <translation>Кэшированное: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Buffer: </source>
        <translation>Буфер: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="509"/>
        <source>Free: </source>
        <translation>Свободное: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="551"/>
        <source>Time passed after system boot</source>
        <translation>Время, прошедшее после загрузки системы</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="579"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation>Средняя загрузка процессора каждые 1, 5 ,15 минут</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="724"/>
        <source>CPU Usage Summary:</source>
        <translation>Сводка по использованию процессора:</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="174"/>
        <source>header_popup</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="175"/>
        <source>Remove Field</source>
        <translation>Удалить поле</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Add Field</source>
        <translation>Добавить поле</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="179"/>
        <source>Session</source>
        <translation>Сеанс</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="183"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="184"/>
        <source>Process</source>
        <translation>Процесс</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="185"/>
        <source>Log</source>
        <translation>Журнал</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Fields</source>
        <translation>Поля</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="191"/>
        <source>Custom Fields</source>
        <translation>Поля пользователя</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="193"/>
        <source>Basic Fields </source>
        <translation>Основные поля </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="195"/>
        <source>Jobs Fields </source>
        <translation>Поля задач </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Memory Fields </source>
        <translation>Поля памяти </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="200"/>
        <source>Scheduling Fields </source>
        <translation>Поля планировщика </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="217"/>
        <source>Select Custom Fields...</source>
        <translation>Выбор полей...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="226"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="227"/>
        <source>Update Period...</source>
        <translation>Период обновления...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="236"/>
        <source>Show Status bar</source>
        <translation>Строка состояния</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="245"/>
        <source>Preferences...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="251"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="252"/>
        <location filename="../qps.cpp" line="1686"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="338"/>
        <source>test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="339"/>
        <source>Copied to Clipboard</source>
        <translation>Скопировано в Буфер обмена</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="391"/>
        <source>context popup</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Renice...</source>
        <translation>Изменить nice...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="393"/>
        <source>Scheduling...</source>
        <translation>Планирование...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Terminate</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="397"/>
        <source>Hangup</source>
        <translation>Разорвать</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="398"/>
        <source>Kill</source>
        <translation>Прервать (SIGKILL)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="399"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="401"/>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="404"/>
        <source>Other Signals</source>
        <translation>Другие сигналы</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="405"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (прерывание)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="407"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (продолжить)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="409"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (остановить)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (выйти)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="413"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (неверная инструкция)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="415"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (принудительное завершение)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="417"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (исключение плавающей точки)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="419"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (ошибка сегментирования)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="421"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (обрыв канала)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="423"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (сигнал таймера)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="425"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (пользовательский 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="427"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (пользовательский 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="429"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (завершился порожденный)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="431"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (остановка с терминала)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="433"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (ввод с терминала)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="435"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (вывод на терминал)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="442"/>
        <source>View Details</source>
        <translation>Просмотр подробностей</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="695"/>
        <source>Show File Path</source>
        <translation>Показывать путь к файлу</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="701"/>
        <source>Show Graph</source>
        <translation>Показывать график</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="707"/>
        <source>Show Control Bar</source>
        <translation>Показывать панель управления</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="718"/>
        <source>Include Child Times</source>
        <translation>Включать время потомков</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="290"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1163"/>
        <location filename="../qps.cpp" line="1194"/>
        <location filename="../qps.cpp" line="1201"/>
        <location filename="../qps.cpp" line="1222"/>
        <location filename="../qps.cpp" line="1256"/>
        <location filename="../qps.cpp" line="1351"/>
        <source>Permission denied</source>
        <translation>Отказ в доступе</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1164"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>У вас нет разрешения на изменение приоритета процессов. Только владелец процесса и суперпользователь может это сделать.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1195"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>У вас нет разрешения на изменение приоритета процесса %1 (%2). Только владелец процесса и суперпользователь может это сделать.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1202"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Только суперпользователь может понизить значение nice.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1223"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Только суперпользователь может изменить политику планировщика и статический приоритет.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1257"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>У вас нет разрешения на смену политики планировщика или приоритета процесса %1 (%2). Только суперпользователь может это сделать.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1318"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Вы действительно хотите завершить выбранные процесс(ы)?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1320"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Вы действительно хотите отправить сигнал SIGHUP выбранным процесс(ам)?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1322"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Вы действительно хотите убить выбранные процесс(ы)?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1331"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1352"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>У вас нет разрешения на отправку сигнала процессу %1 (%2). Только владелец процесса и суперпользователь могут отправлять ему сигналы.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1702"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1704"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - Визуальный менеджер процессов&lt;/h2&gt;
Используется библиотека Qt %3 %2&lt;br&gt;
&lt;br&gt;
&lt;b&gt;Исходный код: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;
&lt;b&gt;Багтрекер: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1724"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Оригинальный разработчик Qps:&lt;/b&gt;
&lt;br&gt;Маттиас Энгдегорд (&lt;i&gt;Mattias Engdegård&lt;/i&gt;) (f91-men@nada.kth.se)&lt;br&gt;
&lt;br&gt;
&lt;b&gt;Участники:&lt;/b&gt;&lt;br&gt;
Olivier.Daudel@u-paris10.fr&lt;br&gt;
jsanchez@todounix.homeip.net&lt;br&gt;
daehyun.yang@gmail.com&lt;br&gt;
Луис Перейра (&lt;i&gt;Luís Pereira&lt;/i&gt;) (luis.artur.pereira@gmail.com)&lt;br&gt;
Элф Гаида (&lt;i&gt;Alf Gaida&lt;/i&gt;) (agaida@siduction.org)&lt;br&gt;
Пауло Лютье (&lt;i&gt;Paulo Lieuthier&lt;/i&gt;) (paulolieuthier@gmail.com)&lt;br&gt;
Жером Лекланш (&lt;i&gt;Jerome Leclanche&lt;/i&gt;) (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Изменить планирование</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Политика планировщика</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (разделение времени)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (реального времени)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (реального времени)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Приоритет (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Неверный ввод</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>Приоритет должен быть в диапазоне 1..99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation>PID, КОМАНДА, ПОЛЬЗОВАТЕЛЬ...</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Сменить приоритет</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>Новое значение nice:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>Хорошо</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>Дескриптор файла</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Протокол (TCP или UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Байт в очереди приема</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Байт в очереди отправки</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Локальный IP-адрес</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Локальный порт</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>Удалённый IP-адрес</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Удалённый порт</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>Состояние соединения</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>Число процессов: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> Это нестабильная альфа-функция
 Она может привести к ошибке сегментации...</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>заголовок</translation>
    </message>
</context>
</TS>
